@@ -101,13 +101,13 @@ ioSS3=function(x,prob=c(0.75,0.5,0.25),yrs=NULL,pts=NULL,nwrms=10,what=c("sims",
        pts.=res[res$year %in% yrs,]
     
     if ("smry" %in% what)
-       smry   =ddply(res,  .(year), function(x) data.frame(stock      =median(x$stock,       na.rm=T),
-                                                           harvest    =median(x$harvest,   na.rm=T),
-                                                           red        =mean(x$red,         na.rm=T),
-                                                           yellow     =mean(x$yellow,      na.rm=T),
-                                                           green      =mean(x$green,       na.rm=T),
-                                                           overFished =mean(x$overFished,  na.rm=T),
-                                                           overFishing=mean(x$overFishing, na.rm=T)))
+       smry   =ddply(res,  .(year), function(x) data.frame(stock      =median(x$stock,       na.rm=TRUE),
+                                                           harvest    =median(x$harvest,   na.rm=TRUE),
+                                                           red        =mean(x$red,         na.rm=TRUE),
+                                                           yellow     =mean(x$yellow,      na.rm=TRUE),
+                                                           green      =mean(x$green,       na.rm=TRUE),
+                                                           overFished =mean(x$overFished,  na.rm=TRUE),
+                                                           overFishing=mean(x$overFishing, na.rm=TRUE)))
     
     if ("wrms" %in% what)
        wrms=res[res$iter %in% sample(unique(res$iter),nwrms),c("iter","year","stock","harvest")]
